==> winnie-0.1.46.tgz: package/properties/render.js <==
'use strict';

var _typeof = require('@babel/runtime/helpers/typeof');
var Ui = require('kenga/utils');
var KeyCodes = require('kenga/key-codes');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _typeof__default = /*#__PURE__*/_interopDefaultLegacy(_typeof);
var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);
var KeyCodes__default = /*#__PURE__*/_interopDefaultLegacy(KeyCodes);

var NULL_COLOR = '#e9ebee';
var colorProps = new Set(['background', 'foreground', 'oddRowsColor', 'evenRowsColor', 'linesColor']);

function onRender(item, viewCell) {
  if (colorProps.has(item.name)) {
    viewCell.innerHTML = '';
    var input = document.createElement('input');
    input.type = 'color';
    input.classList.add('p-winnie-cell-editor');

    if (item.value) {
      input.value = item.value + '';
    } else {
      input.value = NULL_COLOR;
    }

    var colorChanged = function colorChanged(event) {
      item.silent = true;
      item.value = input.value;
    };

    var changeReg = Ui__default['default'].on(input, Ui__default['default'].Events.CHANGE, colorChanged);
    var inputReg = Ui__default['default'].on(input, Ui__default['default'].Events.INPUT, colorChanged);
    Ui__default['default'].on(input, Ui__default['default'].Events.KEYDOWN, function (event) {
      if (event.keyCode === KeyCodes__default['default'].KEY_BACKSPACE || event.keyCode === KeyCodes__default['default'].KEY_DELETE) {
        item.silent = true;
        item.value = null;
        changeReg.removeHandler();
        inputReg.removeHandler();

        try {
          input.value = NULL_COLOR;
        } finally {
          changeReg = Ui__default['default'].on(input, Ui__default['default'].Events.CHANGE, colorChanged);
          inputReg = Ui__default['default'].on(input, Ui__default['default'].Events.INPUT, colorChanged);
        }
      }
    });
    Ui__default['default'].on(input, Ui__default['default'].Events.CLICK, function (event) {
      event.stopPropagation();
    });
    viewCell.appendChild(input);
  } else if (item.name === 'icon' || item.name === 'tab.icon') {
    if (item.value && item.value.src && item.value.getAttribute) {
      /**
       * Warning! Don't change as `item.value.src` because of auto normalization of URI with access to .src property.
       * Some environments do it as their local path + the value of `src` attribute and this ends up with something meaningless for runtime.
       * For example: file:///C:/Users/<user>/AppData/Local/atom/app-1.58.0/resources/app.asar/static/assets/icons/some-icon.svg instead of assets/icons/some-icon.svg .
       * @see ../text-number-field.js
       */
      viewCell.innerHTML = item.value.getAttribute('src');
    }
  } else if (Array.isArray(item.options)) {
    viewCell.innerHTML = '';

    var _input = document.createElement(item.options.length > 1 ? 'select' : 'input');

    if (item.options.length > 1) {
      _input.innerHTML = item.options.map(function (option) {
        return "<option>".concat(option, "</option>");
      }).join('');

      if (item.value) {
        _input.value = item.value;
      }
    } else {
      _input.setAttribute('readonly', 'true');

      _input.setAttribute('style', 'background: transparent');

      if (item.value) {
        _input.value = "".concat(item.value, " - fixed");
      }
    }

    _input.classList.add('p-winnie-cell-editor');

    if (item.options.length > 1) {
      var valueChanged = function valueChanged(event) {
        item.silent = true;
        item.value = _input.value;
      };

      Ui__default['default'].on(_input, Ui__default['default'].Events.CHANGE, valueChanged);
      Ui__default['default'].on(_input, Ui__default['default'].Events.INPUT, valueChanged);
    }

    Ui__default['default'].on(_input, Ui__default['default'].Events.CLICK, function (event) {
      event.stopPropagation();
    });
    Ui__default['default'].on(_input, Ui__default['default'].Events.DBLCLICK, function (event) {
      event.stopPropagation();
    });
    viewCell.appendChild(_input);
  } else if (_typeof__default['default'](item.value) === 'object') {
    viewCell.innerHTML = item.value && item.value['winnie.wrapper'] && item.value['winnie.wrapper'].name ? item.value['winnie.wrapper'].name : '';
  }
}

module.exports = onRender;

==> winnie-0.1.55.tgz: package/properties/render.js <==
'use strict';

var _typeof = require('@babel/runtime/helpers/typeof');
var Ui = require('kenga/utils');
var KeyCodes = require('kenga/key-codes');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _typeof__default = /*#__PURE__*/_interopDefaultLegacy(_typeof);
var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);
var KeyCodes__default = /*#__PURE__*/_interopDefaultLegacy(KeyCodes);

var NULL_COLOR = '#e9ebee';
var colorProps = new Set(['background', 'foreground', 'oddRowsColor', 'evenRowsColor', 'linesColor']);

function onRender(item, viewCell) {
  if (colorProps.has(item.name)) {
    viewCell.innerHTML = '';
    var input = document.createElement('input');
    input.type = 'color';
    input.classList.add('p-winnie-cell-editor');

    if (item.value) {
      input.value = item.value + '';
    } else {
      input.value = NULL_COLOR;
    }

    var colorChanged = function colorChanged(event) {
      item.silent = true;
      item.value = input.value;
    };

    var changeReg = Ui__default["default"].on(input, Ui__default["default"].Events.CHANGE, colorChanged);
    var inputReg = Ui__default["default"].on(input, Ui__default["default"].Events.INPUT, colorChanged);
    Ui__default["default"].on(input, Ui__default["default"].Events.KEYDOWN, function (event) {
      if (event.keyCode === KeyCodes__default["default"].KEY_BACKSPACE || event.keyCode === KeyCodes__default["default"].KEY_DELETE) {
        item.silent = true;
        item.value = null;
        changeReg.removeHandler();
        inputReg.removeHandler();

        try {
          input.value = NULL_COLOR;
        } finally {
          changeReg = Ui__default["default"].on(input, Ui__default["default"].Events.CHANGE, colorChanged);
          inputReg = Ui__default["default"].on(input, Ui__default["default"].Events.INPUT, colorChanged);
        }
      }
    });
    Ui__default["default"].on(input, Ui__default["default"].Events.CLICK, function (event) {
      event.stopPropagation();
    });
    viewCell.appendChild(input);
  } else if (item.name === 'icon' || item.name === 'tab.icon') {
    if (item.value && item.value.src && item.value.getAttribute) {
      /**
       * Warning! Don't change as `item.value.src` because of auto normalization of URI with access to .src property.
       * Some environments do it as their local path + the value of `src` attribute and this ends up with something meaningless for runtime.
       * For example: file:///C:/Users/<user>/AppData/Local/atom/app-1.58.0/resources/app.asar/static/assets/icons/some-icon.svg instead of assets/icons/some-icon.svg .
       * @see ../text-number-field.js
       */
      viewCell.innerHTML = item.value.getAttribute('src');
    }
  } else if (Array.isArray(item.options)) {
    viewCell.innerHTML = '';

    var _input = document.createElement(item.options.length > 1 ? 'select' : 'input');

    if (item.options.length > 1) {
      _input.innerHTML = item.options.map(function (option) {
        return "<option>".concat(option, "</option>");
      }).join('');

      if (item.value) {
        _input.value = item.value;
      }
    } else {
      _input.setAttribute('readonly', 'true');

      _input.setAttribute('style', 'background: transparent');

      if (item.value) {
        _input.value = "".concat(item.value, " - fixed");
      }
    }

    _input.classList.add('p-winnie-cell-editor');

    if (item.options.length > 1) {
      var valueChanged = function valueChanged(event) {
        item.silent = true;
        item.value = _input.value;
      };

      Ui__default["default"].on(_input, Ui__default["default"].Events.CHANGE, valueChanged);
      Ui__default["default"].on(_input, Ui__default["default"].Events.INPUT, valueChanged);
    }

    Ui__default["default"].on(_input, Ui__default["default"].Events.CLICK, function (event) {
      event.stopPropagation();
    });
    Ui__default["default"].on(_input, Ui__default["default"].Events.DBLCLICK, function (event) {
      event.stopPropagation();
    });
    viewCell.appendChild(_input);
  } else if (_typeof__default["default"](item.value) === 'object') {
    viewCell.innerHTML = item.value && item.value['winnie.wrapper'] && item.value['winnie.wrapper'].name ? item.value['winnie.wrapper'].name : '';
  } else if (typeof item.value === 'string' || typeof item.value === 'number') {
    viewCell.innerText = item.value;
  }
}

module.exports = onRender;
